#
# spec file for package python-tsk
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15_python_module_pythons}

%define timestamp 	20210419

Name:           python-tsk
Version:        0~%{timestamp}
Release:        2.6
Summary:        Python bindings for tsk - The SleuthKit
# the included talloc library is LGPL 3
License:        Apache-2.0 AND LGPL-3.0-or-later
URL:            https://github.com/py4n6/pytsk/
Source0:        https://files.pythonhosted.org/packages/source/p/pytsk3/pytsk3-%{timestamp}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  libtalloc-devel
BuildRequires:  postgresql-devel
BuildRequires:  python-rpm-macros
BuildRequires:  sleuthkit-devel >= 4.10.2
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libvhdi)
BuildRequires:  pkgconfig(libvmdk)

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%python_subpackages

%description
The Sleuthkit is a forensic filesystem analysis framework (http://www.sleuthkit.org/). This project is a python 3 binding for the sleuthkit.

%prep
%setup -q -n pytsk3-%{timestamp}
# remove unused libraries with incompatible license, use libtalloc from main repositories
# rm -rf pytsk talloc
# rm -rf pytsk talloc.new

%build
CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# pytest is NOT suppoerted (see gh#py4n6/pytsk#48)
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python ./run_tests.py
}

%files %{python_files}
%defattr(-,root,root)
%doc README
%license LICENSE
%{python_sitearch}/*

%changelog
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Mon May 23 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20210419
  * Updated to be compatible with Sleuthkit 4.10.2
* Mon Jan 20 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20200117
  * Python 2 is officially NOT supported, drop python 2
  * Updated to Sleuthkit 4.7.0
- add a %%check section
- add
  * BuildRequires:  pkgconfig(libvhdi)
  * BuildRequires:  pkgconfig(libvmdk)
- remove unused patch file pytsk_20170128_remove_talloc_build.patch
* Tue Oct  3 2017 Greg.Freemyer@gmail.com
- update to v0~20170802
- implement python singlespec syntax
- add LGPL-3.0+ for the included talloc library
* Sat Feb 25 2017 Greg.Freemyer@gmail.com
- update to v0~20170128
  * Syncs up with recent Sleuthkit versions
  * required by python-plaso 1.5.1 support of Sleuthkit 4.4.0
  * fails to build with Leap 42.1 and older
  * the only known consumer of python-tsk v0~20170128 is python-plaso v1.5.1
  * both python-tsk v0~20170128 and python-plaso v1.5.1 will only be supported on Leap 42.2 and newer
- add a patch to keep setup.py from attempting to build internal talloc lib
- prepare to add python3 support
- add Provides pytsk3 as used by python-plaso 1.5.1
* Fri Aug 15 2014 Greg.Freemyer@gmail.com
- add "Provides: pytsk"  -  pytsk is now in use by upstream dependencies
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to v0~20140506
  * This is just a wrapper for libtsk10, upstream did not provide any release notes
* Wed Sep 11 2013 Greg.Freemyer@gmail.com
- Address legal issues raised in BNC#839248
- update to latest version in source repo (as of 9/10/2013)
  * now uses libtalloc shared library if available
  * remaining GPL licenses changed to Apache-2.0 with permission of relevant copyright holder
- added BuildRequires libtalloc-devel to allow shared library to be used
- added rm -rf talloc and talloc.new to highlight they are not used in the build
* Thu Aug 22 2013 Greg.Freemyer@gmail.com
- fix BuildRequires
  * remove spurious pcre-devel
  * add gcc-c++
* Sat Aug 17 2013 Greg.Freemyer@gmail.com
- update to latest version in source repo
- per author, sleuthkit-devel 4.1 compatibility is only in the source repo
- change version from 0.0.0~ to 0~
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package
